pub enum CallJsonError {
Client(ClientError),
Encode(Error),
Reply(ReplyError),
}Expand description
Failure from Channel::call_json.
Variants
Client(ClientError)
The managed call failed.
Encode(Error)
The request value could not be serialized as JSON.
Reply(ReplyError)
Phoenix rejected the request or the response could not be decoded.