ChannelStatus

Enum ChannelStatus 

pub enum ChannelStatus {
    WaitingForSocket,
    WaitingToJoin,
    Joining,
    Joined,
    Leaving,
    Left,
    Errored,
    Closed,
}
Observable lifecycle state for one channel topic.

Variants



WaitingForSocket

The channel is waiting for the socket to connect.



WaitingToJoin

The socket is connected and the channel has not joined yet.



Joining

A join request is pending.



Joined

The server accepted the join.



Leaving

A leave request is pending.



Left

The channel left successfully.



Errored

A join was rejected or the server sent phx_error.



Closed

The handle was dropped, the server closed it, or the driver stopped.