pub enum PresenceEvent {
Joined {
key: String,
current: Option<Presence>,
joined: Presence,
},
Left {
key: String,
current: Presence,
left: Presence,
},
Synced,
Disconnected,
ChannelLeft,
ChannelClosed,
ChannelError,
}Expand description
A synchronized Presence change or channel lifecycle event.
Variants
Joined
A key or one of its metas joined.
Fields

joined: PresenceEntry or metas added by this update.
Left
A key or one of its metas left.
Fields

current: PresenceEntry before the leave was applied.

left: PresenceEntry or metas removed by this update.
Synced
A full state or diff was applied.
Disconnected
The socket disconnected and local Presence state was cleared.
ChannelLeft
The channel was explicitly left and local state was cleared.
ChannelClosed
The server closed the channel and local state was cleared.
ChannelError
The channel errored and local state was cleared.