pub fn static_connection_config(
config: ConnectionConfig,
) -> ConnectionConfigLoaderExpand description
Creates a loader that clones the same configuration for every attempt.
pub fn static_connection_config(
config: ConnectionConfig,
) -> ConnectionConfigLoaderCreates a loader that clones the same configuration for every attempt.