pub struct ChannelPresence<'a> { /* private fields */ }Expand description
Current Presence state and changes for a joined channel.
The value borrows its Channel so a resynchronization can leave and
rejoin the same channel with a freshly loaded join payload.
Implementations
Sourceimpl<'a> ChannelPresence<'a>
impl<'a> ChannelPresence<'a>
Sourcepub fn requires_resync(&self) -> bool
pub fn requires_resync(&self) -> bool
Returns whether event lag invalidated local state.
Sourcepub async fn resync(&mut self) -> Result<(), ClientError>
pub async fn resync(&mut self) -> Result<(), ClientError>
Clears local state, leaves, and rejoins to request a fresh full state.
Sourcepub async fn next(
&mut self,
) -> Option<Result<PresenceEvent, PresenceStreamError>>
pub async fn next( &mut self, ) -> Option<Result<PresenceEvent, PresenceStreamError>>
Returns the next Presence change or lifecycle event.