pub struct Endpoint { /* private fields */ }Expand description
A Phoenix socket base URL and per-attempt connection configuration.
Implementations
Sourceimpl Endpoint
impl Endpoint
Sourcepub fn new(url: impl AsRef<str>) -> Result<Self, EndpointError>
pub fn new(url: impl AsRef<str>) -> Result<Self, EndpointError>
Parses a ws or wss Phoenix socket URL.
/websocket is appended when the supplied path does not already end
with it.
Sourcepub fn connection_config(self, config: ConnectionConfig) -> Self
pub fn connection_config(self, config: ConnectionConfig) -> Self
Uses a static connection configuration for every attempt.
Sourcepub fn connection_config_loader(self, loader: ConnectionConfigLoader) -> Self
pub fn connection_config_loader(self, loader: ConnectionConfigLoader) -> Self
Installs a loader that is evaluated for every connection attempt.
Sourcepub async fn resolve(
&self,
context: ConnectContext,
) -> Result<ResolvedEndpoint, EndpointError>
pub async fn resolve( &self, context: ConnectContext, ) -> Result<ResolvedEndpoint, EndpointError>
Resolves query parameters, protocol version, and authentication protocols.